==> elgg-1.11.0.zip: elgg-1.11.0/mod/file/languages/ko.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'file' => "파일",
	'file:user' => "%s의 파일",
	'file:friends' => "친구의 파일",
	'file:all' => "모든 파일",
	'file:edit' => "파일 수정",
	'file:more' => "파일 더보기",
	'file:list' => "목록보기",
	'file:group' => "모둠 파일",
	'file:gallery' => "사진첩 보기",
	'file:gallery_list' => "사진첩 혹은 목록 보기",
	'file:num_files' => "표시할 파일의 수",
	'file:user:gallery'=>'%s의 사진첩 보기',
	'file:upload' => "파일 올리기",
	'file:replace' => '파일 내용 대체하기(파일을 바꾸지 않으려면 공백으로 두세요)',
	'file:list:title' => "%s의 %s %s",
	'file:title:friends' => "친구의",

	'file:add' => '파일 올리기',

	'file:file' => "파일",

	'file:list:list' => '목록보기로 변경',
	'file:list:gallery' => '사진첩보기로 변경',

	'file:types' => "올린 파일 형식",

	'file:type:' => '파일',
	'file:type:all' => "모든 파일",
	'file:type:video' => "영상",
	'file:type:document' => "문서",
	'file:type:audio' => "음악",
	'file:type:image' => "그림",
	'file:type:general' => "일반",

	'file:user:type:video' => "%s의 영상",
	'file:user:type:document' => "%s의 문서",
	'file:user:type:audio' => "%s의 음악",
	'file:user:type:image' => "%s의 그림",
	'file:user:type:general' => "%s의 일반 파일",

	'file:friends:type:video' => "친구의 영상",
	'file:friends:type:document' => "친구의 문서",
	'file:friends:type:audio' => "친구의 음악",
	'file:friends:type:image' => "친구의 그림",
	'file:friends:type:general' => "친구의 일반 파일",

	'file:widget' => "파일 위젯",
	'file:widget:description' => "최근 파일을 봅니다",

	'groups:enablefiles' => '모둠 파일 활성화',

	'file:delete:confirm' => "정말 이 파일을 지우겠습니까?",

	'file:upload_limit' => '파일의 허용된 최대 크기는 %s 입니다.',

	'file:tagcloud' => "꼬리표 모음",

	'file:display:number' => "표시할 파일의 수",

	'river:create:object:file' => '%%s가 올린 파일 %s',
	'river:comment:object:file' => '%s가 파일 %s에 댓글을 남겼습니다.',

	'item:object:file' => '파일들',

	'file:notify:summary' => '%s 라는 새 파일',
	'file:notify:subject' => '새 파일: %s',
	'file:notify:body' =>
'%s 가 새 파일을 올렸습니다: %s

%s

파일과 댓글을 봅니다:
%s
',

	/**
	 * Status messages
	 */

	'file:saved' => "파일이 성공적으로 저장되었습니다.",
	'file:deleted' => "파일이 성공적으로 삭제되었습니다.",

	/**
	 * Error messages
	 */

	'file:none' => "파일 없슴.",
	'file:uploadfailed' => "죄송합니다. 파일을 저장할 수 없었습니다.",
	'file:downloadfailed' => "죄송합니다. 지금은 파일을 사용할 수 없습니다.",
	'file:deletefailed' => "지금 파일을 삭제할 수 없었습니다.",
	'file:noaccess' => "이 파일을 변경할 권한이 없습니다.",
	'file:nofile' => "파일을 선택해야합니다.",
);

==> elgg-3.0.5.zip: elgg-3.0.5/mod/file/languages/ko.php <==
<?php
return array(

	'item:object:file' => '파일',
	'collection:object:file' => '파일들',
	'collection:object:file:all' => "모든 파일",
	'collection:object:file:owner' => "%s의 파일",
	'collection:object:file:friends' => "친구의 파일",
	'collection:object:file:group' => "모둠 파일",
	'add:object:file' => "파일 올리기",
	'edit:object:file' => "파일 수정",

	'file:more' => "파일 더보기",
	'file:list' => "목록보기",

	'file:num_files' => "표시할 파일의 수",
	'file:replace' => '파일 내용 대체하기(파일을 바꾸지 않으려면 공백으로 두세요)',
	'file:list:title' => "%s의 %s %s",
	'file:title:friends' => "친구의",

	'file:file' => "파일",

	'file:list:list' => '목록보기로 변경',
	'file:list:gallery' => '사진첩보기로 변경',

	'file:types' => "올린 파일 형식",

	'file:type:' => '파일',
	'file:type:all' => "모든 파일",
	'file:type:video' => "영상",
	'file:type:document' => "문서",
	'file:type:audio' => "음악",
	'file:type:image' => "그림",
	'file:type:general' => "일반",

	'file:user:type:video' => "%s의 영상",
	'file:user:type:document' => "%s의 문서",
	'file:user:type:audio' => "%s의 음악",
	'file:user:type:image' => "%s의 그림",
	'file:user:type:general' => "%s의 일반 파일",

	'file:friends:type:video' => "친구의 영상",
	'file:friends:type:document' => "친구의 문서",
	'file:friends:type:audio' => "친구의 음악",
	'file:friends:type:image' => "친구의 그림",
	'file:friends:type:general' => "친구의 일반 파일",

	'widgets:filerepo:name' => "파일 위젯",
	'widgets:filerepo:description' => "최근 파일을 봅니다",

	'groups:tool:file' => '모둠 파일 활성화',

	'river:object:file:create' => '%s 가 파일 %s을 올렸습니다',
	'river:object:file:comment' => '%s가 파일 %s 에 댓글을 남겼습니다',

	'file:notify:summary' => '%s 라는 새 파일',
	'file:notify:subject' => '새 파일: %s',
	'file:notify:body' => '%s 가 새 파일을 올렸습니다: %s

%s

파일을 보고 댓글을 남깁니다:
%s',

	/**
	 * Status messages
	 */

	'file:saved' => "파일이 성공적으로 저장되었습니다.",
	'entity:delete:object:file:success' => "파일이 성공적으로 삭제되었습니다.",

	/**
	 * Error messages
	 */

	'file:none' => "파일 없슴.",
	'file:uploadfailed' => "죄송합니다. 파일을 저장할 수 없었습니다.",
	'file:noaccess' => "이 파일을 변경할 권한이 없습니다.",
	'file:cannotload' => "파일 올릴 때 오류가 있었습니다",
);
